@@ -46,27 +46,6 @@
 #include <stdint.h>
 #include <sys/types.h>
 
-// This is used by configure.sh to test for OpenBSD.
-#ifdef BC_TEST_OPENBSD
-#ifdef __OpenBSD__
-#error On OpenBSD without _BSD_SOURCE
-#endif // __OpenBSD__
-#endif // BC_TEST_OPENBSD
-
-// This is used by configure.sh to test for FreeBSD.
-#ifdef BC_TEST_FREEBSD
-#ifdef __FreeBSD__
-#error On FreeBSD with _POSIX_C_SOURCE
-#endif // __FreeBSD__
-#endif // BC_TEST_FREEBSD
-
-// This is used by configure.sh to test for macOS.
-#ifdef BC_TEST_APPLE
-#ifdef __APPLE__
-#error On macOS without _DARWIN_C_SOURCE
-#endif // __APPLE__
-#endif // BC_TEST_APPLE
-
 // Windows has deprecated isatty() and the rest of these. Or doesn't have them.
 // So these are just fixes for Windows.
 #ifdef _WIN32
@@ -676,9 +655,13 @@ typedef enum BcMode
 	/// File mode.
 	BC_MODE_FILE,
 
+#if !BC_ENABLE_OSSFUZZ
+
 	/// stdin mode.
 	BC_MODE_STDIN,
 
+#endif // !BC_ENABLE_OSSFUZZ
+
 } BcMode;
 
 /// Do a longjmp(). This is what to use when activating an "exception", i.e., a
