@@ -46,7 +46,7 @@
  * @param argv  The arguments.
  */
 BcStatus
-dc_main(int argc, char* argv[])
+dc_main(int argc, const char* argv[])
 {
 	// All of these just set dc-specific items in BcVm.
 
@@ -61,4 +61,5 @@ dc_main(int argc, char* argv[])
 
 	return bc_vm_boot(argc, argv);
 }
+
 #endif // DC_ENABLED
